OTelFaasTrigger

Enum OTelFaasTrigger 

#[non_exhaustive]
pub enum OTelFaasTrigger { Datasource, Http, PubSub, Timer, Other, }
The value of the OpenTelemetry faas.trigger attribute for a Lambda invocation.

Pass a variant to TracingLayer::with_trigger to describe what kind of event triggers your Lambda function. The value is set on the per-invocation span as the faas.trigger attribute.

The default variant is Datasource, which is appropriate for Lambda functions that read from or write to a data store such as DynamoDB or S3.

See the OTel FaaS attributes registry for the full specification.

Examples

use awssdk_instrumentation::lambda::OTelFaasTrigger;

assert_eq!(OTelFaasTrigger::Datasource.to_string(), "datasource");
assert_eq!(OTelFaasTrigger::Http.to_string(), "http");
assert_eq!(OTelFaasTrigger::PubSub.to_string(), "pubsub");
assert_eq!(OTelFaasTrigger::Timer.to_string(), "timer");
assert_eq!(OTelFaasTrigger::Other.to_string(), "other");

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Datasource

A response to a data source operation such as a database or filesystem read/write.

This is the default. Use it for Lambda functions triggered by DynamoDB Streams, S3 events, or other data-store events.



Http

A response to an inbound HTTP request.

Use this for Lambda functions fronted by API Gateway or a Function URL.



PubSub

A function invoked when messages are sent to a messaging system.

Use this for Lambda functions triggered by SQS, SNS, or EventBridge.



Timer

A function scheduled to run at regular intervals.

Use this for Lambda functions triggered by EventBridge Scheduler or CloudWatch Events rules.



Other

None of the other trigger types apply.